netapp_ontap.models.zapp_nvme_components_subsystem API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.zapp_nvme_components_subsystem`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class ZappNvmeComponentsSubsystemSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the ZappNvmeComponentsSubsystem object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `hosts GET POST PATCH`

    The hosts field of the zapp_nvme_components_subsystem.

  `name GET POST PATCH`

    The name of the subsystem accessing the component. If neither the name nor the UUID is provided, the name defaults to <application-name>_<component-name>, whether that subsystem already exists or not.

  `os_type GET POST PATCH`

    The name of the host OS accessing the component. The default value is the host OS that is running the application.

    Valid choices:

    - linux
    - vmware
    - windows
  `uuid GET POST PATCH`

    The UUID of an existing subsystem to be granted access to the component. Usage: <UUID>